@@ -186,15 +186,28 @@ func (opap *OPAProcessor) processRule(rule *reporthandling.PolicyRule) (*reporth
 	inputResources = workloadinterface.ListMapToMeta(enumeratedData)
 	ruleReport.ListInputKinds = workloadinterface.ListMetaIDs(inputResources)
 
+	for i := range inputResources {
+		opap.AllResources[inputResources[i].GetID()] = inputResources[i]
+	}
+
+	failedResources := workloadinterface.ListMapToMeta(ruleReport.GetFailedResources())
+	for i := range failedResources {
+		if r, ok := opap.AllResources[failedResources[i].GetID()]; !ok {
+			opap.AllResources[failedResources[i].GetID()] = r
+		}
+	}
+	warningResources := workloadinterface.ListMapToMeta(ruleReport.GetWarnignResources())
+	for i := range warningResources {
+		if r, ok := opap.AllResources[warningResources[i].GetID()]; !ok {
+			opap.AllResources[warningResources[i].GetID()] = r
+		}
+	}
+
 	// remove all data from responses, leave only the metadata
 	keepFields := []string{"kind", "apiVersion", "metadata"}
 	keepMetadataFields := []string{"name", "namespace", "labels"}
 	ruleReport.RemoveData(keepFields, keepMetadataFields)
 
-	for i := range inputResources {
-		opap.AllResources[inputResources[i].GetID()] = inputResources[i]
-	}
-
 	return &ruleReport, err
 }
 
